@@ -1,26 +1,33 @@
 import logging
 import os
+import shutil
 import socket
+import sys
 import time
 
 from pyaedt import is_ironpython
 from pyaedt.generic.general_methods import convert_remote_object
 from pyaedt.misc import list_installed_ansysem
 
+logging.basicConfig(stream=sys.stderr, level=logging.INFO)
+logger = logging.getLogger(__name__)
 # import sys
 
 if is_ironpython:
     pyaedt_path = os.path.normpath(os.path.abspath(os.path.dirname(__file__)))
     # sys.path.insert(0, os.path.join(pyaedt_path, "third_party", "ironpython"))
+    from pyaedt.rpc.rpyc_services import GlobalService
+    from pyaedt.rpc.rpyc_services import check_port
     from pyaedt.third_party.ironpython import rpyc_27 as rpyc
-    from pyaedt.third_party.ironpython.rpyc_27.utils.server import ThreadedServer
-    from pyaedt.rpc.rpyc_services import GlobalService, check_port
     from pyaedt.third_party.ironpython.rpyc_27.core import consts
+    from pyaedt.third_party.ironpython.rpyc_27.utils.server import ThreadedServer
 else:
     import rpyc
-    from rpyc.utils.server import ThreadedServer
-    from pyaedt.rpc.rpyc_services import GlobalService, check_port
     from rpyc.core import consts
+    from rpyc.utils.server import ThreadedServer
+
+    from pyaedt.rpc.rpyc_services import GlobalService
+    from pyaedt.rpc.rpyc_services import check_port
 
 # Maximum Stream message size. Set to 256MB
 consts.STREAM_CHUNK = 256000000
@@ -34,14 +41,14 @@ else:
 
 
 def launch_server(port=18000, ansysem_path=None, non_graphical=False):
-    """Starts an rpyc server and starts listening on a specified port.
+    """Starts an RPyC server and listens on a specified port.
 
-    This method has to run on a server machine.
+    This method must run on a server machine.
 
     Parameters
     ----------
     port : int, optional
-        Port that the rpyc server will listen on.
+        Port that the RPyC server is to listen on.
     ansysem_path : str, optional
         Full path to the AEDT installation directory. The default is
         ``None``. This parameter is needed for IronPython on Linux
@@ -59,10 +66,10 @@ def launch_server(port=18000, ansysem_path=None, non_graphical=False):
     """
     port1 = check_port(port)
     if port == 0:
-        print("Error. No available ports.")
+        print("Error. No ports are available.")
         return False
     if port1 != port:
-        print("Port {} is already in use. Starting the server on {}.".format(port, port1))
+        print("Port {} is already in use. Starting the server on port {}.".format(port, port1))
     if os.name == "posix":
         if not ansysem_path:
             aa = list_installed_ansysem()
@@ -176,7 +183,7 @@ def launch_server(port=18000, ansysem_path=None, non_graphical=False):
             "allow_setattr": True,
             "safe_attrs": safe_attrs,
             "allow_delattr": True,
-            "logger": logging.getLogger(__name__),
+            "logger": logger,
         },
     )
     print("Starting the server on port {} on {}.".format(port, hostname))
@@ -192,34 +199,40 @@ def connect(server_name, aedt_client_port):
     server_name : str
         Name of the remote machine to connect to.
     aedt_client_port : int
-        Port that the rpyc server is running on inside AEDT.
+        Port that the RPyC server is running on inside AEDT.
 
     Returns
     -------
-    rpyc object.
+    RPyC object.
     """
     try:
-        return rpyc.connect(server_name, aedt_client_port, config={"sync_request_timeout": None})
+        client = rpyc.connect(
+            server_name, aedt_client_port, config={"allow_public_attrs": True, "sync_request_timeout": None}
+        )
+        client.root.redirect(sys.stdout)
+        client.filemanager = FileManagement(client)
+        return client
     except:
-        return "Error. No connection. Check if AEDT is running and if the port number is correct."
+        return "Error. No connection exists. Check if AEDT is running and if the port number is correct."
 
 
 def client(server_name, server_port=18000, beta_options=None, use_aedt_relative_path=False):
-    """Starts an rpyc client and connects to a remote machine.
+    """Starts an RPyC client and connects to a remote machine.
 
     Parameters
     ----------
     server_name : str
         Name of the remote machine to connect.
     server_port : int, optional
-        Port that the rpyc server is running on.
+        Port that the RPyC server is running on.
     beta_options : list, optional
         List of beta options to apply to the new service. The default is ``None``.
     use_aedt_relative_path : bool, optional
-        Whether to use aedt executable full path or relative path call. Needed in case linux environment is defined.
+        Whether to use AEDT executable full path or relative path call. This parameter is needed
+        if a Linux environment is defined.
     Returns
     -------
-    rpyc object.
+    RPyC object.
 
     Examples
     --------
@@ -261,7 +274,7 @@ def client(server_name, server_port=18000, beta_options=None, use_aedt_relative_
             t -= 1
             time.sleep(1)
     if not c:
-        print("Failing to connect to {} on port {}. Check the settings".format(server_name, server_port))
+        print("Failed to connect to {} on port {}. Check the settings".format(server_name, server_port))
         return False
     port = c.root.start_service(server_name, beta_options, use_aedt_relative_path=use_aedt_relative_path)
     if not port:
@@ -286,97 +299,104 @@ def client(server_name, server_port=18000, beta_options=None, use_aedt_relative_
         return "Error. No connection."
 
 
-def upload(localpath, remotepath, server_name, server_port=18000):
-    """Upload a file or a directory to the given remote path.
+class FileManagement(object):
+    """Class to manage file transfer."""
 
-    Parameters
-    ----------
-    localpath : str
-        Path to the local file or directory.
-    remotepath : str
-        Remote path.
-    server_name : str
-        Name of the server to connect to.
-    server_port : int, optional
-        Port number. The default is ``18000``.
-    """
-    if os.path.isdir(localpath):
-        _upload_dir(localpath, remotepath, server_name, server_port)
-    elif os.path.isfile(localpath):
-        _upload_file(localpath, remotepath, server_name, server_port)
+    def __init__(self, client):
+        self.client = client
 
+    def upload(self, localpath, remotepath):
+        """Upload a file or a directory to the given remote path.
 
-def download(remotepath, localpath, server_name, server_port=18000):
-    """Download a file or a directory from a given remote path to the local path.
+        Parameters
+        ----------
+        localpath : str
+            Path to the local file or directory.
+        remotepath : str
+            Remote path.
+        """
+        if os.path.isdir(localpath):
+            self._upload_dir(localpath, remotepath)
+        elif os.path.isfile(localpath):
+            self._upload_file(localpath, remotepath)
 
-    Parameters
-    ----------
-    remotepath : str
-        Remote path.
-    localpath : str
-        Path to the local file or directory.
-    server_name : str
-        Name of the server to connect to.
-    server_port : int, optional
-        Port number. The default is ``18000``.
-    """
-    if os.path.isdir(remotepath):
-        _download_dir(remotepath, localpath, server_name, server_port)
-    elif os.path.isfile(remotepath):
-        _download_file(localpath, remotepath, server_name, server_port)
+    def download_folder(self, remotepath, localpath):
+        """Download a directory from a given remote path to the local path.
 
+        Parameters
+        ----------
+        remotepath : str
+            Remote path.
+        localpath : str
+            Path to the local file or directory.
+        """
+        self._download_dir(remotepath, localpath)
 
-def _upload_file(local_file, remote_file, server_name, server_port=18000):
-    c = rpyc.connect(server_name, server_port, config={"sync_request_timeout": None})
-    if c.root.path_exists(remote_file):
-        return "File already exists on the server."
-    with open(local_file, "rb") as f:
-        lines = f.readlines()
-        new_file = c.root.create(remote_file)
-        for line in lines:
-            new_file.write(line)
-        new_file.close()
+    def download_file(self, remotepath, localpath):
+        """Download a file from a given remote path to the local path.
 
+        Parameters
+        ----------
+        remotepath : str
+            Remote path.
+        localpath : str
+            Path to the local file or directory.
+        """
+        self._download_file(remotepath, localpath)
 
-def _upload_dir(localpath, remotepath, server_name, server_port=18000):
-    c = rpyc.connect(server_name, server_port, config={"sync_request_timeout": None})
-    if c.root.path_exists(remotepath):
-        return "Folder already exists on the server."
-    c.root.makedirs(remotepath)
-    for fn in os.listdir(localpath):
-        lfn = os.path.join(localpath, fn)
-        rfn = os.path.join(remotepath, fn)
-        _upload_file(lfn, rfn, server_name, server_port=18000)
+    def _upload_file(self, local_file, remote_file):
+        if self.client.root.path_exists(remote_file):
+            logger.error("File already exists on the server.")
+            return False
+        new_file = self.client.root.create(remote_file)
+        local = open(local_file, "rb")
+        shutil.copyfileobj(local, new_file)
+        logger.info("File %s uploaded to %s", local_file, remote_file)
 
+    def _upload_dir(self, localpath, remotepath):
+        if self.client.root.path_exists(remotepath):
+            logger.warning("Folder already exists on the server.")
+        self.client.root.makedirs(remotepath)
+        i = 0
+        for fn in os.listdir(localpath):
+            lfn = os.path.join(localpath, fn)
+            rfn = remotepath + "/" + fn
+            if os.path.isdir(rfn):
+                self._upload_dir(lfn, rfn)
+            else:
+                self._upload_file(lfn, rfn)
+            i += 1
+        logger.info("Directory %s uploaded. %s files copied", localpath, i)
 
-def _download_file(remote_file, local_file, server_name, server_port=18000):
-    c = rpyc.connect(server_name, server_port, config={"sync_request_timeout": None})
-    if os.path.exists(local_file):
-        return "File already exists on the server."
-    remote = c.root.open(remote_file)
-    lines = remote.readlines()
-    with open(local_file, "wb") as new_file:
-        for line in lines:
-            new_file.write(line)
-        new_file.close()
+    def _download_file(self, remote_file, local_file):
+        if os.path.exists(local_file):
+            logger.warning("File already exists on the client.")
+        remote = self.client.root.open(remote_file)
+        new_file = open(local_file, "wb")
+        shutil.copyfileobj(remote, new_file)
+        logger.info("File %s downloaded to %s", remote_file, local_file)
 
-
-def _download_dir(remotepath, localpath, server_name, server_port=18000):
-    c = rpyc.connect(server_name, server_port, config={"sync_request_timeout": None})
-    if os.path.exists(localpath):
-        return "Folder already exists on the local machine."
-    if not os.path.isdir(localpath):
-        os.makedirs(localpath)
-    for fn in c.root.listdir(remotepath):
-        lfn = os.path.join(localpath, fn)
-        rfn = os.path.join(remotepath, fn)
-        _download_file(rfn, lfn, server_name, server_port=18000)
+    def _download_dir(self, remotepath, localpath):
+        if os.path.exists(localpath):
+            logger.warning("Folder already exists on the local machine.")
+        if not os.path.isdir(localpath):
+            os.makedirs(localpath)
+        i = 0
+        for fn in self.client.root.listdir(remotepath):
+            lfn = os.path.join(localpath, fn)
+            rfn = remotepath + "/" + fn
+            if self.client.root.isdir(rfn):
+                self._download_dir(rfn, lfn)
+            else:
+                self._download_file(rfn, lfn)
+            i += 1
+        logger.info("Directory %s downloaded. %s files copied", localpath, i)
 
 
 def launch_ironpython_server(
     aedt_path=None, non_graphical=False, port=18000, launch_client=True, use_aedt_relative_path=False
 ):
-    """Start a process in IronPython and launch the rpc server on the specified port given an AEDT path on Linux.
+    """Start a process in IronPython and launch the RPyC server on the specified port given an AEDT path on Linux.
 
     .. warning::
         Remote CPython to IronPython may have some limitations.
@@ -392,7 +412,7 @@ def launch_ironpython_server(
         Whether to start AEDT in non-graphical mode. The default is ``False``, in which case
         AEDT is started in graphical mode.
     port : int, optional
-        Port on which the rpc server is to listen. The default is ``18000``.
+        Port on which the RPyC server is to listen on. The default is ``18000``.
     launch_client : bool, optional
         Whether to launch the client. The default is ``True``.
     use_aedt_relative_path : bool, optional
@@ -402,12 +422,13 @@ def launch_ironpython_server(
     launch_client : bool, optional
         Whether to launch the client. The default is ``True.``
     use_aedt_relative_path : bool, optional
-        Whether to use aedt executable full path or relative path call. Needed in case linux environment is defined.
-        aedt_path parameter is still needed since it is necessary to retrieve ipy64.exe full path.
+        Whether to use the AEDT executable full path or relative path call. This parameter is needed
+        if the Linux environment is defined. The ``aedt_path`` parameter is still needed because it
+        is necessary to retrieve the ``ipy64.exe`` full path.
 
     Returns
     -------
-    rpyc object.
+    RPyC object.
 
     Examples
     --------
@@ -441,7 +462,7 @@ def launch_ironpython_server(
         str(port1),
     ]
     if not os.path.exists(os.path.join(aedt_path, "common", "IronPython", "ipy64.exe")):
-        print("Check the aedt_path and retry.")
+        print("Check the AEDT path and retry.")
         return False
     proc = subprocess.Popen(" ".join(command), shell=True)
     print("Process {} started on {}".format(proc.pid, socket.getfqdn()))
