@@ -189,7 +189,7 @@ class EdbHfss(object):
 
     @pyaedt_function_handler()
     def create_resistor_on_pin(self, pos_pin, neg_pin, rvalue=1, resistor_name=""):
-        """Create a voltage source.
+        """Create a Resistor boundary between two given pins.
 
         Parameters
         ----------
@@ -382,7 +382,7 @@ class EdbHfss(object):
         rvalue=1,
         resistor_name="",
     ):
-        """Create a voltage source.
+        """Create a Resistor boundary between two given nets.
 
         Parameters
         ----------
@@ -923,7 +923,7 @@ class EdbHfss(object):
             sweep.UseQ3DForDC = simulation_setup.use_q3d_for_dc
             sweep.RelativeSError = simulation_setup.relative_error
             sweep.InterpUsePortImpedance = False
-            sweep.EnforceCausality = simulation_setup.start_frequency
+            sweep.EnforceCausality = simulation_setup.enforce_causality
             # sweep.EnforceCausality = False
             sweep.EnforcePassivity = simulation_setup.enforce_passivity
             sweep.PassivityTolerance = simulation_setup.passivity_tolerance
