@@ -13,7 +13,10 @@ from pyaedt.generic.DataHandlers import float_units
 from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modeler.GeometryOperators import GeometryOperators
-from pyaedt.modules.Boundary import BoundaryObject, MaxwellParameters
+from pyaedt.modeler.Object3d import EdgePrimitive
+from pyaedt.modeler.Object3d import FacePrimitive
+from pyaedt.modules.Boundary import BoundaryObject
+from pyaedt.modules.Boundary import MaxwellParameters
 
 
 class Maxwell(object):
@@ -50,12 +53,12 @@ class Maxwell(object):
 
     @pyaedt_function_handler()
     def change_symmetry_multiplier(self, value=1):
-        """Set the Design Symmetry Multiplier to the selected value.
+        """Set the Design Symmetry Multiplier to a specified value.
 
         Parameters
         ----------
         value : int, optional
-            Value used as the Design Symmetry Multiplier coefficient. The default value is ``1``.
+            Value to use as the Design Symmetry Multiplier coefficient. The default value is ``1``.
 
         Returns
         -------
@@ -154,10 +157,11 @@ class Maxwell(object):
         return_path : list, str, optional
             Return path. The default is ``infinite``
         group_sources : dict, list optional
-            Dictionary consisting of ``{Group Name: list of source names}``. This dictionary is used to add
-            multiple groups. A list of strings could be also defined. The default is not define a group.
+            Dictionary consisting of ``{Group Name: list of source names}`` to add
+            multiple groups. You can also define a list of strings. The default is ``None``.
         branches : : list, int, optional
-            Number of branches. The default is 1.
+            Number of branches. The default is ``None``, which indicates that only one
+            branch exists.
 
         Returns
         -------
@@ -236,7 +240,7 @@ class Maxwell(object):
                 group_sources = None
                 branches = None
                 turns = ["1"] * len(sources)
-                self.logger.info("Infinite is the only return path option in EddyCurrent")
+                self.logger.info("Infinite is the only return path option in EddyCurrent.")
                 return_path = ["infinite"] * len(sources)
 
         if self.solution_type not in ["Transient", "ElectricTransient"]:
@@ -305,7 +309,7 @@ class Maxwell(object):
                 self.boundaries.append(bound)
                 return bound
         else:
-            self.logger.error("Solution Type has not Matrix Parameter")
+            self.logger.error("Solution type does not have matrix parameters")
             return False
 
     @pyaedt_function_handler()
@@ -323,7 +327,7 @@ class Maxwell(object):
         keep_modifications : bool, optional
             Whether to save the changes. The default value is ``False``.
         python_interpreter : str, optional
-             The default value is ``None``.
+             Python interpreter to use. The default value is ``None``.
         aedt_lib_dir : str, optional
              Full path to the ``pyaedt`` directory. The default value is ``None``.
 
@@ -467,13 +471,13 @@ class Maxwell(object):
 
     @pyaedt_function_handler()
     def setup_y_connection(self, windings_name=None):
-        """Setup the y connection.
+        """Setup the Y connection.
 
         Parameters
         ----------
         winding_name : list, optional
-            List of windings. For instance ["PhaseA", "PhaseB", "PhaseC"].
-            The default value is ``None``. In that case the design have none Y connection.
+            List of windings. For example, ``["PhaseA", "PhaseB", "PhaseC"]``.
+            The default value is ``None``, in which case the design has no Y connection.
 
         Returns
         -------
@@ -487,8 +491,8 @@ class Maxwell(object):
 
         Examples
         --------
-        Setup Y Connection for three existing windings respectively named ``PhaseA``, ``PhaseB``, ``PhaseC``.
-        This will create one ``YConnection`` group containing those 3 phases.
+        Set up the Y connection for three existing windings named ``PhaseA``, ``PhaseB``, and ``PhaseC``.
+        This creates one ``YConnection`` group containing these three phases.
 
         >>> from pyaedt import Maxwell2d
         >>> aedtapp = Maxwell2d("Motor_EM_R2019R3.aedt")
@@ -568,7 +572,7 @@ class Maxwell(object):
             if type(object_list[0]) is str:
                 props = OrderedDict({"Objects": object_list, "Current": amplitude, "IsPositive": swap_direction})
             else:
-                self.logger.warning("Input has to be a 2D Object.")
+                self.logger.warning("Input must be a 2D object.")
                 return False
         bound = BoundaryObject(self, name, props, "Current")
         if bound.create():
@@ -608,7 +612,7 @@ class Maxwell(object):
         positive_movement : bool, optional
             Whether movement is positive. The default is ``True``.
         start_position : float or str, optional
-            Starting position of the movement. The default is ``o``. If a float
+            Starting position of the movement. The default is ``0``. If a float
             value is used, default modeler units are applied.
         periodic_translate : bool, optional
             Whether movement is periodic. The default is ``False``.
@@ -881,11 +885,11 @@ class Maxwell(object):
         res : float, optional
             Resistance in ohms. The default is ``0``.
         ind : float, optional
-            Henry. The default is ``0``.
+            Henry (H). The default is ``0``.
         voltage : float, optional
             Voltage value. The default is ``0``.
         parallel_branches : int, optional
-            The number of parallel branches. The default is ``1``.
+            Number of parallel branches. The default is ``1``.
         name : str, optional
             Name of the boundary. The default is ``None``.
 
@@ -1038,7 +1042,8 @@ class Maxwell(object):
         is_virtual : bool, optional
             Whether the force is virtual. The default is ``True.``
         force_name : str, optional
-            Name of the force. The default is ``None``.
+            Name of the force. The default is ``None``, in which case the default
+            name is used.
 
         Returns
         -------
@@ -1099,7 +1104,8 @@ class Maxwell(object):
         axis : str, optional
             Axis to apply the torque to. The default is ``"Z"``.
         torque_name : str, optional
-            Name of the torque. The default is ``None``.
+            Name of the torque. The default is ``None``, in which
+            case the default name is used.
 
         Returns
         -------
@@ -1221,6 +1227,72 @@ class Maxwell(object):
         )
         return True
 
+    @pyaedt_function_handler()
+    def assign_symmetry(self, entity_list, symmetry_name=None, is_odd=True):
+        """Assign symmetry boundary.
+
+        Parameters
+        ----------
+        entity_list : list
+            List IDs or :class:`pyaedt.modeler.Object3d.EdgePrimitive` or
+            :class:`pyaedt.modeler.Object3d.FacePrimitive`.
+        symmetry_name : str, optional
+            Name of the symmetry.
+        is_odd : bool, optional
+            Type of the symmetry. The default is ``True`,` in which case the H field
+            is tangential to the boundary. If ``False``, the H field is normal to
+            the boundary.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oModule.AssignSymmetry
+        """
+        try:
+            if symmetry_name is None:
+                symmetry_name = generate_unique_name("Symmetry")
+
+            object_list = []
+            if entity_list:
+                if self.design_type == "Maxwell 2D":
+                    for entity in entity_list:
+                        if isinstance(entity, EdgePrimitive):
+                            edge_id = entity.id
+                        elif isinstance(entity, int):
+                            edge_id = entity
+                        else:
+                            msg = "The input is not an edge object or an integer."
+                            raise ValueError(msg)
+                        object_list.append(edge_id)
+                    prop = OrderedDict({"Name": symmetry_name, "Edges": object_list, "IsOdd": is_odd})
+                else:
+                    for entity in entity_list:
+                        if isinstance(entity, FacePrimitive):
+                            face_id = entity.id
+                        elif isinstance(entity, int):
+                            face_id = entity
+                        else:
+                            msg = "The input is not a valid face object or an integer."
+                            raise ValueError(msg)
+                        object_list.append(face_id)
+                    prop = OrderedDict({"Name": symmetry_name, "Faces": object_list, "IsOdd": is_odd})
+            else:
+                msg = "At least one edge must be provided."
+                ValueError(msg)
+
+            bound = BoundaryObject(self, symmetry_name, prop, "Symmetry")
+            if bound.create():
+                self.boundaries.append(bound)
+                return bound
+            return True
+        except:
+            return False
+
     def __enter__(self):
         return self
 
@@ -1252,7 +1324,7 @@ class Maxwell3d(Maxwell, FieldAnalysis3D, object):
     specified_version : str, optional
         Version of AEDT to use. The default is ``None``, in which case
         the active version or latest installed version is used. This
-        parameter is ignored when Script is launched within AEDT.
+        parameter is ignored when a script is launched within AEDT.
     non_graphical : bool, optional
         Whether to launch AEDT in non-graphical mode. The default
         is ``False``, in which case AEDT is launched in graphical
@@ -1262,24 +1334,25 @@ class Maxwell3d(Maxwell, FieldAnalysis3D, object):
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
         machine. The default is ``True``. This parameter is ignored
-        when Script is launched within AEDT.
+        when a script is launched within AEDT.
     close_on_exit : bool, optional
         Whether to release AEDT on exit. The default is ``False``.
     student_version : bool, optional
         Whether to open the AEDT student version. The default is
-        ``False``. This parameter is ignored when Script is launched
+        ``False``. This parameter is ignored when a script is launched
         within AEDT.
     machine : str, optional
-        Machine name to which connect the oDesktop Session. Works only on 2022R2.
-        Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
-        If machine is `"localhost"` the server will also start if not present.
+        Machine name to connect the oDesktop session to. This works only in 2022 R2
+        or later. The remote server must be up and running with the command
+        `"ansysedt.exe -grpcsrv portnum"`. If the machine is `"localhost"`, the
+        server also starts if not present.
     port : int, optional
-        Port number of which start the oDesktop communication on already existing server.
-        This parameter is ignored in new server creation. It works only on 2022R2.
-        Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
+        Port number on which to start the oDesktop communication on an already existing server.
+        This parameter is ignored when a new server is created. It works only in 2022 R2 or later.
+        The remote server must be up and running with the command `"ansysedt.exe -grpcsrv portnum"`.
     aedt_process_id : int, optional
-        Only used when ``new_desktop_session = False``, specifies by process ID which instance
-        of Electronics Desktop to point PyAEDT at.
+        Process ID for the instance of AEDT to point PyAEDT at. The default is
+        ``None``. This parameter is only used when ``new_desktop_session = False``.
 
     Examples
     --------
@@ -1368,7 +1441,7 @@ class Maxwell2d(Maxwell, FieldAnalysis3D, object):
     specified_version : str, optional
         Version of AEDT to use. The default is ``None``, in which case
         the active version or latest installed version is used.
-        This parameter is ignored when Script is launched within AEDT.
+        This parameter is ignored when a script is launched within AEDT.
     non_graphical : bool, optional
         Whether to launch AEDT in non-graphical mode. The default
         is ``False``, in which case AEDT is launched in graphical mode.
@@ -1376,23 +1449,25 @@ class Maxwell2d(Maxwell, FieldAnalysis3D, object):
     new_desktop_session : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
-        machine. The default is ``True``. This parameter is ignored when Script is launched within AEDT.
+        machine. The default is ``True``. This parameter is ignored when
+        a script is launched within AEDT.
     close_on_exit : bool, optional
         Whether to release AEDT on exit. The default is ``False``.
     student_version : bool, optional
         Whether to open the AEDT student version. The default is ``False``.
-        This parameter is ignored when Script is launched within AEDT.
+        This parameter is ignored when a script is launched within AEDT.
     machine : str, optional
-        Machine name to which connect the oDesktop Session. Works only on 2022R2.
-        Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
-        If machine is `"localhost"` the server will also start if not present.
+        Machine name to connect the oDesktop session to. This works only in 2022 R2
+        or later. The remote server must be up and running with the command
+        `"ansysedt.exe -grpcsrv portnum"`. If the machine is `"localhost"`,
+        the server also starts if not present.
     port : int, optional
-        Port number of which start the oDesktop communication on already existing server.
-        This parameter is ignored in new server creation. It works only on 2022R2.
-        Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
+        Port number of which to start the oDesktop communication on an already existing
+        server. This parameter is ignored when creating a new server. It works only in 2022
+        R2 or later. The remote server must be up and running with the command `"ansysedt.exe -grpcsrv portnum"`.
     aedt_process_id : int, optional
-        Only used when ``new_desktop_session = False``, specifies by process ID which instance
-        of Electronics Desktop to point PyAEDT at.
+        Process ID for the instance of AEDT to point PyAEDT at. The default is
+        ``None``. This parameter is only used when ``new_desktop_session = False``.
 
     Examples
     --------
@@ -1467,7 +1542,7 @@ class Maxwell2d(Maxwell, FieldAnalysis3D, object):
 
     @property
     def xy_plane(self):
-        """Maxwell 2D plane between `True` and `False`."""
+        """Maxwell 2D plane between ``True`` and ``False``."""
         return self.design_solutions.xy_plane
 
     @xy_plane.setter
@@ -1574,7 +1649,8 @@ class Maxwell2d(Maxwell, FieldAnalysis3D, object):
         edge_list : list
             List of edges.
         bound_name : str, optional
-            Name of the boundary. The default is ``None``.
+            Name of the boundary. The default is ``None``, in which
+            case the default name is used.
 
         Returns
         -------
@@ -1610,7 +1686,8 @@ class Maxwell2d(Maxwell, FieldAnalysis3D, object):
         vectorvalue : float, optional
             Value of the vector. The default is ``0``.
         bound_name : str, optional
-            Name of the boundary. The default is ``None``.
+            Name of the boundary. The default is ``None``, in which
+            case the default name is used.
 
         Returns
         -------
@@ -1656,7 +1733,8 @@ class Maxwell2d(Maxwell, FieldAnalysis3D, object):
         same_as_master : bool, optional
             Whether the B-Field of the slave edge and master edge are the same. The default is ``True``.
         bound_name : str, optional
-            Name of the master boundary. The name of the slave boundary will have a ``_dep`` suffix.
+            Name of the master boundary. The default is ``None``, in which case the default name
+            is used. The name of the slave boundary has a ``_dep`` suffix.
 
         Returns
         -------
@@ -1700,20 +1778,21 @@ class Maxwell2d(Maxwell, FieldAnalysis3D, object):
 
     @pyaedt_function_handler()
     def assign_end_connection(self, objects, resistance=0, inductance=0, bound_name=None):
-        """Assign End connection to a list of objects.
+        """Assign an end connection to a list of objects.
 
         Parameters
         ----------
         objects : list of int or str or :class:`pyaedt.modeler.Object3d.Object3d`
-            List of objects to apply end connection.
+            List of objects to assign an end connection to.
         resistance : float or str, optional
-            Resistance value. If float is provided then it is assumed in Ohm.
-            The default value is "0ohm".
+            Resistance value. If float is provided, the units are assumed to be ohms.
+            The default value is ``0``,
         inductance : float or str, optional
-            Inductance value. If float is provided then it is assumed in Henry.
-            The default value is "0H".
+            Inductance value. If a float is provided, the units are assumed to Henry (H).
+            The default value is ``0``.
         bound_name : str, optional
-            Name of the End connection boundary.
+            Name of the end connection boundary. The default is ``None``, in which case the
+            default name is used.
 
         Returns
         -------
