@@ -15,9 +15,9 @@ if not is_ironpython:
 
 from pyaedt import constants
 from pyaedt.generic.general_methods import generate_unique_name
+from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modules.MaterialLib import Material
-from pyaedt.generic.general_methods import is_ironpython
 
 LAYERS = {"s": "signal", "g": "ground", "d": "dielectric"}
 
@@ -1591,7 +1591,7 @@ class Patch(CommonObject, object):
             )
             application.assign_coating(self._aedt_object.name, signal_layer.material)
         application.modeler.set_working_coordinate_system("Global")
-        application.modeler.subtract(blank_list=[signal_layer.name], tool_list=[patch_name], keepOriginals=True)
+        application.modeler.subtract(blank_list=[signal_layer.name], tool_list=[patch_name], keep_originals=True)
 
     @property
     def frequency(self):
@@ -2017,7 +2017,7 @@ class Trace(CommonObject, object):
                 matname=signal_layer.material_name,
             )
         application.modeler.set_working_coordinate_system("Global")
-        application.modeler.subtract(blank_list=[signal_layer.name], tool_list=[line_name], keepOriginals=True)
+        application.modeler.subtract(blank_list=[signal_layer.name], tool_list=[line_name], keep_originals=True)
 
     @property
     def frequency(self):
