@@ -5,11 +5,12 @@ This module contains the `Materials` class.
 from __future__ import absolute_import  # noreorder
 
 import copy
+import fnmatch
 import json
 import os
-import fnmatch
 import re
 
+from pyaedt import settings
 from pyaedt.generic.DataHandlers import _arg2dict
 from pyaedt.generic.general_methods import _create_json_file
 from pyaedt.generic.general_methods import _retry_ntimes
@@ -158,9 +159,14 @@ class Materials(object):
             # m = load_entire_aedt_file(amat)
             # mats.extend(list(m.keys()))
             mats.extend(get_mat_list(amat))
-
-        mats.remove("$index$")
-        mats.remove("$base_index$")
+        try:
+            mats.remove("$index$")
+        except ValueError:
+            pass
+        try:
+            mats.remove("$base_index$")
+        except ValueError:
+            pass
         mats.extend(self.odefinition_manager.GetProjectMaterialNames())
         return mats
 
@@ -233,6 +239,8 @@ class Materials(object):
             return self.material_keys[mat.lower()]
         elif mat.lower() in self._mat_names_aedt_lower:
             return self._aedmattolibrary(mat)
+        elif settings.remote_api:
+            return self._aedmattolibrary(mat)
         return False
 
     @pyaedt_function_handler()
@@ -584,13 +592,14 @@ class Materials(object):
         return data
 
     def _load_from_project(self):
-        mats = self.odefinition_manager.GetProjectMaterialNames()
-        for el in mats:
-            if el not in list(self.material_keys.keys()):
-                try:
-                    self._aedmattolibrary(el)
-                except Exception as e:
-                    self.logger.info("aedmattolibrary failed for material %s", el)
+        if self.odefinition_manager:
+            mats = self.odefinition_manager.GetProjectMaterialNames()
+            for el in mats:
+                if el not in list(self.material_keys.keys()):
+                    try:
+                        self._aedmattolibrary(el)
+                    except Exception as e:
+                        self.logger.info("aedmattolibrary failed for material %s", el)
 
     @pyaedt_function_handler()
     def _aedmattolibrary(self, matname):
@@ -604,7 +613,7 @@ class Materials(object):
         -------
         :class:`pyaedt.modules.Material.Material`
         """
-        if matname not in self.odefinition_manager.GetProjectMaterialNames():
+        if matname not in self.odefinition_manager.GetProjectMaterialNames() and not settings.remote_api:
             matname = self._get_aedt_case_name(matname)
         props = {}
         _arg2dict(list(_retry_ntimes(20, self.omaterial_manager.GetData, matname)), props)
