@@ -6,6 +6,8 @@ import threading
 import site
 
 import sys
+import time
+
 from pyaedt import generate_unique_name
 from pyaedt.generic.general_methods import env_path
 
@@ -760,12 +762,26 @@ class GlobalService(rpyc.Service):
         # (to init the service, if needed)
         self.connection = connection
         self._processes = {}
+        self._edb = []
         pass
 
     def on_disconnect(self, connection):
         # code that runs after the connection has already closed
         # (to finalize the service, if needed)
-        pass
+        if os.name != "posix":
+            sys.stdout = sys.__stdout__
+        for edb in self._edb:
+            try:
+                edb.close_edb()
+            except:
+                pass
+
+
+    def exposed_redirect(self, stdout):
+        sys.stdout = stdout
+
+    def exposed_restore(self):
+        sys.stdout = sys.__stdout__
 
     @staticmethod
     def aedt_grpc(port=None, beta_options=None, use_aedt_relative_path=False, non_graphical=True):
@@ -776,12 +792,18 @@ class GlobalService(rpyc.Service):
         port : int
             gRPC port on which the AEDT session has started.
         """
+        from pyaedt.generic.general_methods import grpc_active_sessions
+
+        sessions = grpc_active_sessions()
         if not port:
             port = check_port(random.randint(18500, 20000))
 
         if port == 0:
             print("Error. No ports are available.")
             return False
+        elif port in sessions:
+            print("AEDT Session already opened on port {}.".format(port))
+            return True
         ansysem_path = ""
         if os.name == "posix":
             ansysem_path = os.getenv("PYAEDT_SERVER_AEDT_PATH", "")
@@ -817,6 +839,18 @@ class GlobalService(rpyc.Service):
             command = [aedt_exe, "-grpcsrv", str(port), ng_feature]
 
         subprocess.Popen(command)
+        timeout = 60
+        s = socket.socket()
+        machine_name = socket.getfqdn()
+        while timeout > 0:
+            try:
+                s.connect((machine_name, port))
+            except socket.error:
+                timeout -= 2
+                time.sleep(2)
+            else:
+                s.close()
+                timeout = 0
         print("Service has started on port {}".format(port))
         return port
 
@@ -863,15 +897,15 @@ class GlobalService(rpyc.Service):
         :class:`pyaedt.edb.Edb`
             Edb class.
         """
-        edb = Edb(edbpath=edbpath,
+        self._edb.append(Edb(edbpath=edbpath,
                   cellname=cellname,
                   isreadonly=isreadonly,
                   edbversion=edbversion,
                   isaedtowned=isaedtowned,
                   oproject=oproject,
                   student_version=student_version,
-                  use_ppe=use_ppe, )
-        return edb
+                  use_ppe=use_ppe, ))
+        return self._edb[-1]
 
     def exposed_start_service(self, hostname, beta_options=None, use_aedt_relative_path=False):
         """Starts and listens to a new PyAEDT service.
@@ -988,7 +1022,7 @@ class GlobalService(rpyc.Service):
 
     def exposed_open(self, filename):
         f = open(filename, "rb")
-        return rpyc.restricted(f, ["readlines", "close"], [])
+        return rpyc.restricted(f, ["read", "readlines", "close"], [])
 
     def exposed_create(self, filename):
         if os.path.exists(filename):
@@ -1011,3 +1045,6 @@ class GlobalService(rpyc.Service):
         if os.path.exists(remotepath):
             return True
         return False
+
+    def exposed_isdir(self, remotepath):
+        return os.path.isdir(remotepath)
